@@ -7,7 +7,7 @@ from ipywidgets import (
 
 from traitlets import (
     Float, Unicode, Int, Tuple, List, Instance, Bool, Dict, Enum,
-    link, observe, default, validate, TraitError
+    link, observe, default, validate, TraitError, Union
 )
 
 from branca.colormap import linear, ColorMap
@@ -74,6 +74,8 @@ class Layer(Widget, InteractMixin):
     base = Bool(False).tag(sync=True)
     bottom = Bool(False).tag(sync=True)
     popup = Instance(Widget, allow_none=True, default_value=None).tag(sync=True, **widget_serialization)
+    popup_min_width = Int(400).tag(sync=True)
+    popup_max_height = Int(400).tag(sync=True)
 
     options = List(trait=Unicode).tag(sync=True)
 
@@ -189,9 +191,8 @@ class Popup(UILayer):
     ).tag(sync=True, **widget_serialization)
 
     # Options
-    max_width = Int(300).tag(sync=True, o=True)
-    min_width = Int(50).tag(sync=True, o=True)
-    max_height = Int(allow_none=True, default_value=None).tag(sync=True, o=True)
+    min_width = Int(400).tag(sync=True, o=True)
+    max_height = Int(400).tag(sync=True, o=True)
     auto_pan = Bool(True).tag(sync=True, o=True)
     auto_pan_padding_top_left = List(allow_none=True, default_value=None).tag(sync=True, o=True)
     auto_pan_padding_bottom_right = List(allow_none=True, default_value=None).tag(sync=True, o=True)
@@ -237,6 +238,13 @@ class TileLayer(RasterLayer):
         self._load_callbacks.register_callback(callback, remove=remove)
 
 
+class LocalTileLayer(TileLayer):
+    _view_name = Unicode('LeafletLocalTileLayerView').tag(sync=True)
+    _model_name = Unicode('LeafletLocalTileLayerModel').tag(sync=True)
+
+    path = Unicode('').tag(sync=True)
+
+
 class WMSLayer(TileLayer):
     _view_name = Unicode('LeafletWMSLayerView').tag(sync=True)
     _model_name = Unicode('LeafletWMSLayerModel').tag(sync=True)
@@ -368,7 +376,7 @@ class Polyline(Path):
 
     # Options
     smooth_factor = Float(1.0).tag(sync=True, o=True)
-    no_clip = Bool(False).tag(sync=True, o=True)
+    no_clip = Bool(True).tag(sync=True, o=True)
 
 
 class Polygon(Polyline):
@@ -549,6 +557,11 @@ class Control(Widget):
         return [name for name in self.traits(o=True)]
 
 
+class FullScreenControl(Control):
+    _view_name = Unicode('LeafletFullScreenControlView').tag(sync=True)
+    _model_name = Unicode('LeafletFullScreenControlModel').tag(sync=True)
+
+
 class LayersControl(Control):
     _view_name = Unicode('LeafletLayersControlView').tag(sync=True)
     _model_name = Unicode('LeafletLayersControlModel').tag(sync=True)
@@ -631,8 +644,8 @@ class SplitMapControl(Control):
     _view_name = Unicode('LeafletSplitMapControlView').tag(sync=True)
     _model_name = Unicode('LeafletSplitMapControlModel').tag(sync=True)
 
-    left_layer = Instance(TileLayer).tag(sync=True, **widget_serialization)
-    right_layer = Instance(TileLayer).tag(sync=True, **widget_serialization)
+    left_layer = Union((Instance(Layer), List(Instance(Layer)))).tag(sync=True, **widget_serialization)
+    right_layer = Union((Instance(Layer), List(Instance(Layer)))).tag(sync=True, **widget_serialization)
 
     @default('left_layer')
     def _default_left_layer(self):
